==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/user_status/l10n/it.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Stati recenti",
    "No recent status changes" : "Nessun cambio di stato recente",
    "In a meeting" : "In una riunione",
    "Commuting" : "Pendolare",
    "Out sick" : "In malattia",
    "Vacationing" : "In vacanza",
    "Out of office" : "Fuori sede",
    "Working remotely" : "Lavoro da remoto",
    "In a call" : "In una chiamata",
    "User status" : "Stato utente",
    "Clear status after" : "Togli lo stato dopo",
    "Emoji for your status message" : "Emoji per il tuo messaggio di stato",
    "What is your status?" : "Qual è il tuo stato?",
    "Predefined statuses" : "Stati predefiniti",
    "Previously set" : "Impostato in precedenza",
    "Reset status" : "Ripristina stato",
    "Set status" : "Imposta stato",
    "Online status" : "Stato in linea",
    "Status message" : "Messaggio di stato",
    "Your status was set automatically" : "Stato impostato automaticamente",
    "Clear status message" : "Cancella il messaggio di stato",
    "Set status message" : "Imposta messaggio di stato",
    "Reset status to \"{icon} {message}\"" : "Ripristina stato a \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Ripristina stato a \"{message}\"",
    "Reset status to \"{icon}\"" : "Ripristina stato a \"{icon}\"",
    "There was an error saving the status" : "Si è verificato un errore durante il salvataggio dello stato",
    "There was an error clearing the status" : "Si è verificato un errore durante la rimozione dello stato",
    "There was an error reverting the status" : "Si è verificato un errore ripristinando lo stato",
    "Don't clear" : "Non togliere",
    "Today" : "Oggi",
    "This week" : "Questa settimana",
    "Online" : "In linea",
    "Away" : "Assente",
    "Do not disturb" : "Non disturbare",
    "Invisible" : "Invisibile",
    "Offline" : "Non in linea",
    "There was an error saving the new status" : "Si è verificato un errore durante il salvataggio del nuovo stato",
    "30 minutes" : "30 minuti",
    "1 hour" : "1 ora",
    "4 hours" : "4 ore",
    "Mute all notifications" : "Silenzia tutte le notifiche",
    "Appear offline" : "Mostrati non in linea",
    "View profile" : "Vedi profilo",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/user_status/l10n/it.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Stati recenti",
    "No recent status changes" : "Nessun cambio di stato recente",
    "In a meeting" : "In una riunione",
    "Commuting" : "Pendolare",
    "Out sick" : "In malattia",
    "Vacationing" : "In vacanza",
    "Out of office" : "Fuori sede",
    "Working remotely" : "Lavoro da remoto",
    "In a call" : "In una chiamata",
    "User status" : "Stato utente",
    "Clear status after" : "Togli lo stato dopo",
    "Emoji for your status message" : "Emoji per il tuo messaggio di stato",
    "What is your status?" : "Qual è il tuo stato?",
    "Predefined statuses" : "Stati predefiniti",
    "Previously set" : "Impostato in precedenza",
    "Reset status" : "Ripristina stato",
    "Reset status to \"{icon} {message}\"" : "Ripristina stato a \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Ripristina stato a \"{message}\"",
    "Reset status to \"{icon}\"" : "Ripristina stato a \"{icon}\"",
    "There was an error saving the status" : "Si è verificato un errore durante il salvataggio dello stato",
    "There was an error clearing the status" : "Si è verificato un errore durante la rimozione dello stato",
    "There was an error reverting the status" : "Si è verificato un errore ripristinando lo stato",
    "Set status" : "Imposta stato",
    "Online status" : "Stato in linea",
    "Status message" : "Messaggio di stato",
    "Set absence period" : "Imposta periodo di assenza",
    "Set absence period and replacement" : "Imposta periodo di assenza e sostituzione",
    "Your status was set automatically" : "Stato impostato automaticamente",
    "Clear status message" : "Cancella il messaggio di stato",
    "Set status message" : "Imposta messaggio di stato",
    "Don't clear" : "Non togliere",
    "Today" : "Oggi",
    "This week" : "Questa settimana",
    "Online" : "In linea",
    "Away" : "Assente",
    "Do not disturb" : "Non disturbare",
    "Invisible" : "Invisibile",
    "Offline" : "Non in linea",
    "There was an error saving the new status" : "Si è verificato un errore durante il salvataggio del nuovo stato",
    "30 minutes" : "30 minuti",
    "1 hour" : "1 ora",
    "4 hours" : "4 ore",
    "Mute all notifications" : "Silenzia tutte le notifiche",
    "Appear offline" : "Mostrati non in linea"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
